PublicKeySet class

Contains Web Push (public) keys information necessary for the application server to encrypt notification for this instance, following RFC8291

Constructors

PublicKeySet(String pubKey, String auth)

Properties

auth → String
Auth secret, base64url encoded without padding.
final
hashCode → int
The hash code for this object.
no setterinherited
pubKey → String
P-256 Public key, in uncompressed format, base64url encoded without padding.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited