PushMessage class

Contains the push message. It has been correctly decrypted if decrypted is true.

Constructors

PushMessage(Uint8List content, bool decrypted)

Properties

content → Uint8List
Content of the push message.
final
decrypted → bool
Whether it has been correctly decrypted.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited